@@ -1,11 +1,10 @@
 import logging
 
 import click
-
-from .core import set_level
+from .core import _normalize_logger
 
 
-def simple_verbosity_option(*names, **kwargs):
+def simple_verbosity_option(logger=None, *names, **kwargs):
     '''A decorator that adds a `--verbosity, -v` option to the decorated
     command.
 
@@ -15,6 +14,9 @@ def simple_verbosity_option(*names, **kwargs):
 
     if not names:
         names = ['--verbosity', '-v']
+    if isinstance(logger, str) and logger.startswith('-'):
+        raise ValueError('Since click-log 0.2.0, the first argument must now '
+                         'be a logger.')
 
     kwargs.setdefault('default', 'INFO')
     kwargs.setdefault('metavar', 'LVL')
@@ -22,6 +24,8 @@ def simple_verbosity_option(*names, **kwargs):
     kwargs.setdefault('help', 'Either CRITICAL, ERROR, WARNING, INFO or DEBUG')
     kwargs.setdefault('is_eager', True)
 
+    logger = _normalize_logger(logger)
+
     def decorator(f):
         def _set_level(ctx, param, value):
             x = getattr(logging, value.upper(), None)
@@ -29,7 +33,7 @@ def simple_verbosity_option(*names, **kwargs):
                 raise click.BadParameter(
                     'Must be CRITICAL, ERROR, WARNING, INFO or DEBUG, not {}'
                 )
-            set_level(x)
+            logger.setLevel(x)
 
         return click.option(*names, callback=_set_level, **kwargs)(f)
     return decorator
